#
# spec file for package movit
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           movit
Version:        1.5.3
Release:        2.2
%define _sonum  7
Summary:        GPU video filter library
License:        GPL-2.0+
Group:          Development/Libraries/C and C++
Url:            https://movit.sesse.net
Source0:        https://movit.sesse.net/movit-%{version}.tar.gz
Source1:        COPYING
BuildRequires:  gcc-c++
BuildRequires:  make
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(egl)
BuildRequires:  pkgconfig(eigen3)
BuildRequires:  pkgconfig(epoxy)
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(sdl)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Movit is a library for video filters. It uses the GPU present in many
computers to accelerate computation of common filters and
transitions, facilitating real-time HD video editing.

%package -n libmovit%{_sonum}
Summary:        GPU video filter library
Group:          Development/Libraries/C and C++
Provides:       %{name} = %{version}
Obsoletes:      %{name} < %{version}
Requires:       %{name}-data

%description -n libmovit%{_sonum}
Movit is a library for video filters. It uses the GPU present in many
computers to accelerate computation of common filters and
transitions, facilitating real-time HD video editing.

This package contains the Movit shared library.

%package        devel
Summary:        Development files for the Movit GPU video filter library
Group:          Development/Libraries/C and C++
Requires:       libmovit%{_sonum} = %{version}

%description    devel
Movit is a library for video filters. It uses the GPU present in many
computers to accelerate computation of common filters and
transitions, facilitating real-time HD video editing.

This package contains the development files (library and header files).

%package        data
Summary:        Data files for the Movit GPU video filter library
Group:          Development/Libraries/C and C++
BuildArch:      noarch

%description    data
Movit is a library for video filters. It uses the GPU present in many
computers to accelerate computation of common filters and
transitions, facilitating real-time HD video editing.

This package contains the architecture-independent data files.

%prep
%setup -q
cp -av %{SOURCE1} .

%build
%configure --disable-static --datarootdir=%{_datadir}/libmovit%{_sonum}
make %{?_smp_mflags} TESTS=

%install
%make_install

rm %{buildroot}%{_libdir}/libmovit.la

%post -n libmovit%{_sonum} -p /sbin/ldconfig
%postun -n libmovit%{_sonum} -p /sbin/ldconfig

%files -n libmovit%{_sonum}
%defattr(-,root,root)
%doc README NEWS COPYING
%{_libdir}/libmovit.so.*

%files data
%defattr(-,root,root)
%doc COPYING
%{_datadir}/%{name}/

%files devel
%defattr(-,root,root)
%doc COPYING
%{_libdir}/libmovit.so
%{_includedir}/%{name}
%{_libdir}/pkgconfig/%{name}.pc

%changelog
* Fri Aug 11 2017 antoine.belvire@opensuse.org
- Update to 1.5.3:
  * Various bugfixes.
- Don't use gcc6-c++ for Leap anymore: It builds fine with default
  compiler again.
* Tue Jul 11 2017 olaf@aepfle.de
- Use gcc6-c++ for Leap42 and SLE12 (C++14 needed).
* Mon Jul 10 2017 antoine.belvire@opensuse.org
- Update to 1.5.2:
  * The texture generation for ResampleEffect (when the size is
    changed) now uses less CPU.
  * Work around an NVIDIA driver threading bug by aggressively
    caching VAOs.
  * Update soname to libmovit.so.7.
- Remove call to autogen.sh as we don't patch Makefile.in anymore.
* Sun Jun  4 2017 antoine.belvire@opensuse.org
- Update to 1.5.1:
  * Allow YCbCrInput to change input format after finalize.
  * Some minor YCbCrInput bugfixes.
* Sun Mar 26 2017 antoine.belvire@opensuse.org
- Update to 1.5.0:
  * Support interleaved Y'CbCr input (4:4:4 in a single texture).
  * Support 10-bit and 12-bit Y'CbCr, both for input and output.
  * Limited support for having multiple Y'CbCr outputs from a
    chain.
  * Allow changing the Y'CbCr output coefficients runtime, i.e.
    after finalize.
  * Fix an issue where the last pass would have been rendered with
    the sRGB flag set, which confused Qt applications running in
    certain NVIDIA configurations.
* Fri Mar  3 2017 olaf@aepfle.de
- Remove googletest dependency because tests can not be run without
  an X display
- Drop movit-1.2.0-use-gtest-shared-library.patch
* Sat Dec 17 2016 antoine.belvire@opensuse.org
- Update to 1.4.0:
  * Allow setting the intermediate format for chains, instead of
    hardcoding it at 16-bit RGBA; advanced users can use this to
    e.g. ask for 8-bit sRGB intermediates, reducing the amount of
    memory bandwidth needed at the cost of reduced precision.
    Whether this is a good tradeoff or not depends on the exact
    chain and your requirements.
  * Fix an issue where a (cached) shader program could be used
    from multiple threads at a time, causing the uniforms to
    contain unpredictable values.
  * Make the error printed on check_error() slightly friendlier:
    Include the enum if possible, and print it to stderr instead
    of stdout.
* Sun Oct 16 2016 jengelh@inai.de
- Trim filler words from descriptions
* Tue Oct 11 2016 toddrme2178@gmail.com
- Update year
- Fix version testing ("=" instead of "==")
- Delete unneeded files instead of excluding.
- Split data files into their own subpackage.
* Sun Oct  9 2016 antoine.belvire@opensuse.org
- Add and install missing license file (COPYING, it's the GPLv3)
- Install changelog file (NEWS)
* Sat Mar  5 2016 antoine.belvire@opensuse.org
- Update to 1.3.2:
  * Fix several bugs
* Tue Feb  9 2016 antoine.belvire@opensuse.org
- Update to 1.3.0:
  * Fix several bugs
  * Add a deinterlacer based on YADIF
  * Add new GLSL 1.50 shaders
  * Remove support for GLSL 1.10
- Use the official tarball as source
* Mon Dec 21 2015 antoine.belvire@opensuse.org
- Initial package: movit-1.2.0
